HOST = 'localhost'
PORT = 7777

ENCODING = 'ascii'

BYTES_RECV_SIZE = 1000000
ACT_PRESENCE = 'presence'
ACT_PROBE = 'probe'
ACT_MESSAGE = 'msg'
ACT_ADD_CONTACT = 'add_contact'
ACT_DEL_CONTACT = 'del_contact'
ACT_GET_CONTACTS = 'get_contacts'
ACT_QUIT = 'quit'
ACT_AUTHENTICATE = 'authenticate'
ACT_JOIN = 'join'
ACT_LEAVE = 'leave'
ACT_EXIT = 'exit'
ACT_GET_CLIENTS = 'get_clients'

RESP_BASE_NOTIF = 100
RESP_IMORTANT_NOTIF = 101

RESP_OK = 200
RESP_OBJ_CREATED = 201
RESP_ACCEPTED = 202

RESP_WRONG_REQUEST = 400
RESP_NOT_AUTHORIZED = 401
RESP_WRONG_CREDENTIALS = 402
RESP_FORBIDDEN = 403
RESP_NOT_FOUND = 404
RESP_CONFLICT = 409
RESP_GONE = 410

RESP_BAD_GATEWAY = 500
