# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'client_chat.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(640, 480)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_contacts = QtWidgets.QLabel(self.centralwidget)
        self.label_contacts.setAlignment(QtCore.Qt.AlignCenter)
        self.label_contacts.setObjectName("label_contacts")
        self.gridLayout_2.addWidget(self.label_contacts, 0, 0, 1, 1)
        self.edit_message = QtWidgets.QLineEdit(self.centralwidget)
        self.edit_message.setObjectName("edit_message")
        self.gridLayout_2.addWidget(self.edit_message, 4, 1, 1, 1)
        self.btn_send_message = QtWidgets.QPushButton(self.centralwidget)
        self.btn_send_message.setObjectName("btn_send_message")
        self.gridLayout_2.addWidget(self.btn_send_message, 5, 1, 1, 1)
        self.label_messages = QtWidgets.QLabel(self.centralwidget)
        self.label_messages.setAlignment(QtCore.Qt.AlignCenter)
        self.label_messages.setObjectName("label_messages")
        self.gridLayout_2.addWidget(self.label_messages, 0, 1, 1, 1)
        self.list_contacts = QtWidgets.QListView(self.centralwidget)
        self.list_contacts.setObjectName("list_contacts")
        self.gridLayout_2.addWidget(self.list_contacts, 2, 0, 3, 1)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btn_add_contact = QtWidgets.QPushButton(self.centralwidget)
        self.btn_add_contact.setObjectName("btn_add_contact")
        self.horizontalLayout.addWidget(self.btn_add_contact)
        self.btn_del_contact = QtWidgets.QPushButton(self.centralwidget)
        self.btn_del_contact.setObjectName("btn_del_contact")
        self.horizontalLayout.addWidget(self.btn_del_contact)
        self.horizontalLayout_5.addLayout(self.horizontalLayout)
        self.gridLayout_2.addLayout(self.horizontalLayout_5, 5, 0, 1, 1)
        self.label_help = QtWidgets.QLabel(self.centralwidget)
        self.label_help.setObjectName("label_help")
        self.gridLayout_2.addWidget(self.label_help, 3, 1, 1, 1)
        self.list_messages = QtWidgets.QListView(self.centralwidget)
        self.list_messages.setObjectName("list_messages")
        self.gridLayout_2.addWidget(self.list_messages, 2, 1, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 640, 22))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Messenger"))
        self.label_contacts.setText(_translate("MainWindow", "Contacts"))
        self.btn_send_message.setText(_translate("MainWindow", "Send"))
        self.label_messages.setText(_translate("MainWindow", "Messages"))
        self.btn_add_contact.setText(_translate("MainWindow", "Add contact"))
        self.btn_del_contact.setText(_translate("MainWindow", "Delete contact"))
        self.label_help.setText(_translate("MainWindow", "Type text below and click \"Send\""))
